#<profile4xi profile = "02" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "acquirerproxy4xi.py">
#<abstract4xi abstract = "provides class AcquirerProxy4Xi" />
#<refer4xi reference = "managers.py" />
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------


# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'AcquirerProxy4Xi' ]
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
try:                 # system ones
    import os
    import sys
    import signal 
except:
    pass
try:                 # threading ones       
    import threading                
    import _thread   
except:
    pass
try:
    import _winapi
except:
    pass    
try:                 # most-common ones
    import weakref
    import array
    import queue         
except:
    pass
try:                 # rare ones
    from traceback import format_exc          
except:
    pass 
       
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
try:                             # Binary ones
    import _multiprocessing
except:
    pass
try:                             # Python ones
    from multiprocessing.managers import BaseProxy
    from multiprocessing.managers import AcquirerProxy
except:
    print("acquirerproxy4xi.py *** failed in from from multiprocessing.managers import AcquirerProxy ***")
#"
#/>
 
# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from baseproxy4xi import BaseProxy4Xi
from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi
from print4xi import print4xi
from time4xi import time4xi
#"
#/>

#
# =================================================================================================
#<class4xi class = "AcquirerProxy4Xi" base = "BaseProxy4Xi" child = "None" synopsis = "
#  
# conditionproxy4xi.py:                                
#     class ConditionProxy4Xi(AcquirerProxy4Xi)
#"
#>
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# =================================================================================================
#
class AcquirerProxy4Xi(BaseProxy4Xi):
    '''
    AcquirerProxy4Xi class inherited from BaseProxy4Xi for ConditionProxy4Xi
    '''

    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi exposure = "
    _exposed_ = ('acquire', 'release', 'sense', 'reason', 'ace')         
    #"
    #/>
                                

    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "acquire-of-AcquirerProxy4Xi" usage = "acquires with blocking">
    # ---------------------------------------------------------------------------------------------
    def acquire(self, blocking=True, timeout=None):
        '''
        acquires with blocking    
        '''

        # -----------------------------------------------------------------------------------------    
        # (Step 1/2) 
        # -----------------------------------------------------------------------------------------          
        class2print = 'AcquirerProxy4Xi'
        method2print = 'acquire'
        
        message2print = "{(Step 1/2a) started" + "; acquire-of-AcquirerProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          

        message2print = "{(Step 1/2b) passed" + "; blocking-passed-to-acquire-of-AcquirerProxy4Xi: " + str(blocking) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        
        message2print = "{(Step 1/2c) passed" + "; timeout-passed-to-acquire-of-AcquirerProxy4Xi: " + str(timeout) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   

        # -----------------------------------------------------------------------------------------    
        # (Step 2/2)
        # -----------------------------------------------------------------------------------------        
        args2xi = (blocking,) if timeout is None else (blocking, timeout)
        message2print = "{(Step 2/2a) set" + "; args2xi-set-by-acquire-of-AcquirerProxy4Xi to: " + str(args2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)     
        
        
        message2print = "{(Step 2/2b) passing" + "; args2xi-passing-to-callmethod-of-acquirerproxy2xi-by-acquire-of-AcquirerProxy4Xi': " + str(args2xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          

                          
        message2print = "{(Step 2/2c) returning" + "; callmethod-of-acquirerproxy2xi-returning-by-acquire-of-AcquirerProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)      
        
        return self._callmethod('acquire', args2xi)
 
    #</methodize4xi> 
            
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "release-of-AcquirerProxy4Xi" usage = "releases">
    # ---------------------------------------------------------------------------------------------
    def release(self):
        '''
        releases    
        '''
        class2print = 'AcquirerProxy4Xi'
        method2print = 'release'
        
        
        message2print = "{started" + "; release-of-AcquirerProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
      
         
             
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{passing" + "; release-passing-to-callmethod-of-acquirerproxy2xi-by-release-of-AcquirerProxy4Xi: release" + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
 
          
        message2print = "{returning" + "; callmethod-of-acquirerproxy2xi-returning-by-release-of-AcquirerProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)      
        
                
        return self._callmethod('release')
       
    #</methodize4xi> 
            
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "enter-of-AcquirerProxy4Xi" usage = "returns with self">                            
    # ---------------------------------------------------------------------------------------------
    def __enter__(self):
        '''
        returns with self    
        '''    
        class2print = 'AcquirerProxy4Xi'
        method2print = '__enter__'
        
        
        message2print = "{started" + "; enter-of-AcquirerProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
   
  
        
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------        

        message2print = "{passing" + "; acquire-passing-to-callmethod-of-acquirerproxy2xi-by-enter-of-AcquirerProxy4Xi: acquire" + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
          
          
        message2print = "{returning" + "; callmethod-of-acquirerproxy2xi-returning-by-enter-of-AcquirerProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)      
  

        return self._callmethod('acquire')
   
    #</methodize4xi> 
            
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "exit-of-AcquirerProxy4Xi" usage = "exits exc_type, exc_val, exc_tb">                            
    # ---------------------------------------------------------------------------------------------
    def __exit__(self, exc_type, exc_val, exc_tb):
        '''
        exits exc_type, exc_val, exc_tb    
        '''    
        class2print = 'AcquirerProxy4Xi'
        method2print = '__exit__'
        
        
        message2print = "{started" + "; exit-of-AcquirerProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
    
            
        message2print = "{passed" + "; exc-type-passed-to-exit-of-AcquirerProxy4Xi: " + str(exc_type) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   

        message2print = "{passed" + "; exc-val-passed-to-exit-of-AcquirerProxy4Xi: " + str(exc_val) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
    
        message2print = "{passed" + "; exc-tb-passed-to-exit-of-AcquirerProxy4Xi: " + str(exc_tb) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   


        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------        
          
        message2print = "{returning" + "; callmethod-of-acquirerproxy2xi-returning-by-exit-of-AcquirerProxy4Xi: " + str(self._callmethod) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)      
      
        return self._callmethod('release')
  
    #</methodize4xi> 
            
                                        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-AcquirerProxy4Xi" usage = "senses AcquirerProxy4Xi class objects">
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        method sense: senses AcquirerProxy4Xi class objects
        '''
          
        
        class2print = 'AcquirerProxy4Xi'
        method2print = 'sense'
        
        
        message2print = "{started" + "; sense-of-AcquirerProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
   
   
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; AcquirerProxy4Xi-sensing-by-sense-of-AcquirerProxy4Xi: " + str(AcquirerProxy4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; kb2xi-got-by-sense-of-AcquirerProxy4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb2xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['inheritance-of-acquirerproxy2xi'] = "BaseProxy4Xi-inherited-by-acquirerproxy2xi-of-AcquirerProxy4Xi"    
        except:
            message2print = "{yielded" + "; kb2xi-yielded-by-sense-of-AcquirerProxy4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 

     
        message2print = "{sensed" + "; AcquirerProxy4Xi-sensed-by-sense-of-AcquirerProxy4Xi: " + str(AcquirerProxy4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)      
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{returning" + "; kb2xi-returning-by-sense-of-AcquirerProxy4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)             
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi> 
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-AcquirerProxy4Xi" usage = "reasons AcquirerProxy4Xi class objects">
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        method reason: reasons AcquirerProxy4Xi class objects
        '''
                 
        
        class2print = 'AcquirerProxy4Xi'
        method2print = 'reason'

        
        
        message2print = "{started" + "; reason-of-AcquirerProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
     
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{reasoning" + "; AcquirerProxy4Xi-reasoning-by-reason-of-AcquirerProxy4Xi: "  + str(AcquirerProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{got" + "; kb4xi-got-by-reason-of-AcquirerProxy4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        
          
        
        message2print = "{reasoned" + "; AcquirerProxy4Xi-reasoned-by-reason-of-AcquirerProxy4Xi: "  + str(AcquirerProxy4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb4xi-returning-by-reason-of-AcquirerProxy4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)             
          
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi> 
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-AcquirerProxy4Xi" usage = "aces AcquirerProxy4Xi class objects">
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        method ace: aces AcquirerProxy4Xi class objects 
        '''
               
        
        
        class2print = 'AcquirerProxy4Xi'
        method2print = 'ace'
        
        
        message2print = "{started" + "; ace-of-AcquirerProxy4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
  
   
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; AcquirerProxy4Xi-acing-by-ace-of-AcquirerProxy4Xi: " + "AcquirerProxy4Xi" + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; kb8xi-got-by-ace-of-AcquirerProxy4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)


        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{aced" + "; AcquirerProxy4Xi-aced-by-ace-of-AcquirerProxy4Xi: " + "AcquirerProxy4Xi" + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb8xi-returning-by-ace-of-AcquirerProxy4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)             
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------           
    #</methodize4xi> 
    
#</class4xi>
#</program4xi> 

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_none4xi.txt
#   sense-test-none4xi.xml
#   reason-test-none4xi.xml
#   ace-test-none4xi.xml
#"
#>

# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>
 
#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of acquirerproxy4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>



